==> babeldoc-0.1.8.tar.gz: babeldoc-0.1.8/docs/CONTRIBUTOR_REWARD.md <==
# BabelDOC/PDFMathTranslate 贡献者奖励规则

### **月度活跃贡献者奖励规则**
**一、资格标准**
1. **贡献类型要求**
   - 需提交 **至少 1 个有效 PR**（Pull Request），或进行 **PR 审核、文档编写** 等贡献。
   - 有效贡献定义：
     - 非简单的文档错别字修复
     - 非简单的代码格式化调整（如仅调整缩进、空格等）
     - 需做出实质性贡献（如功能开发、Bug 修复、性能优化、架构调整、技术文档编写、PR 审核等）
   - 示例合格贡献：新增功能模块、修复逻辑错误、优化算法效率、编写技术文档等

2. **时间范围**
   - 每月 1 日至月末最后一天合并的 PR 计入当月统计

**二、申请流程**
1. **申请条件**
   - PR 需被成功合并至[funstory-ai/BabelDOC](https://github.com/funstory-ai/BabelDOC/pulls) 仓库或 [Byaidu/PDFMathTranslate](https://github.com/Byaidu/PDFMathTranslate/pulls)的主分支。
   - 审核 PR、撰写 wiki 等贡献也必须是以上两个仓库。
   - 同一贡献者每月仅可申请一次（无论提交 PR 数量）
   - 同一贡献者每月最多可以获得 1 个兑换码
   - 对于 PR，只有发起者可以申请兑换码
   - 仅可使用当月的贡献申请兑换码（特殊情况请联系 aw@funstory.ai 说明）

2. **申请方式**
   - 发送邮件至 **aw@funstory.ai**
   - 邮件标题格式：`[贡献者会员兑换码申请] GitHub用户名-月份`（例：`[贡献者会员兑换码申请] awwaawwa-2024-07`）
   - 邮件正文需包含：
     - GitHub 用户名
     - 合并 PR 的完整链接
   - 附件要求：
     - PR 页面完整截图（需包含合并状态、仓库名称及点击头像后弹出来的侧边栏，如下图所示）

![附件示例](images/contributor_reward_example.png)

3. **奖励说明**
   - 奖励内容：[沉浸式翻译（Immersive Translate）](https://immersivetranslate.com/zh-Hans/pricing/)月度会员兑换码
   - 兑换码使用：在[沉浸式翻译官网兑换页](https://immersivetranslate.com/zh-Hans/exchange)输入即可激活
   - 会员权益：沉浸式翻译 Pro 会员一个月（详见[官网价格页](https://immersivetranslate.com/zh-Hans/pricing/)说明）
   - 兑换码为专属福利，不可转让

**三、审核与发放**
1. **审核周期**
   - 我们会尽力在收到申请邮件后 1 个工作日内完成审核
   - 审核时间可能因申请数量、审核复杂度等因素有所延长
   - 审核通过后，兑换码将通过邮件方式发送
   - 若审核未通过，我们会通过邮件说明原因

2. 兑换码规则：
   - 使用方式：[官网兑换页](https://immersivetranslate.com/zh-Hans/exchange)输入兑换码激活
   - 权益内容：月度会员（具体权益见[官网价格页](https://immersivetranslate.com/zh-Hans/pricing/)说明）
   - 不可转让

**四、注意事项**
1. **禁止行为**
   - 将完整功能拆分为多个无关 PR 提交
   - 提交质量不合格或具有潜在危害的代码
   - 提供虚假或误导性的申请材料

2. **特别说明**
   - funstory.ai 保留对贡献价值的评估权、规则的最终解释权等所有必要权利
   - 规则如有更新，将提前 1 天在 [BabelDOC GitHub PR](https://github.com/funstory-ai/BabelDOC/pulls) 公告
   - 过期未使用的兑换码不予补发
   - 自 2025 年 2 月 1 日起的贡献可以申请兑换码
   - 为了确认您是 Pull Request (PR) 的发起者，防止他人冒领，我们可能会要求您使用发起者账号在 PR 下方留言指定的随机数字。


---
### **常见问题解答（FAQ）**

Q：如何判断文档翻译贡献是否有效？
A：系统性的人工翻译（如完整章节的翻译并经过人工校对）视为有效贡献。零散段落翻译或仅依赖机器翻译的内容不计入有效贡献。

Q：兑换码过期了可以补发吗？
A：为确保公平性，过期的兑换码将不予补发，请在有效期内及时使用。

Q：为什么这个文档是中文的？
A：因为目前应该是中文贡献者多吧，所以就先写中文的。后面再撰写英文版的。

---
**规则公示**：本规则文档存放于 BabelDOC 仓库 [CONTRIBUTOR_REWARD.md](https://github.com/funstory-ai/BabelDOC/blob/main/docs/CONTRIBUTOR_REWARD.md)。

==> babeldoc-0.1.22.tar.gz: babeldoc-0.1.22/docs/CONTRIBUTOR_REWARD.md <==
# BabelDOC/PDFMathTranslate 贡献者奖励规则

## 月度活跃贡献者奖励规则

### 一、资格标准
#### **贡献类型要求**
   - 需提交 **至少 1 个有效 PR**（Pull Request），或进行 **PR 审核、文档编写** 等贡献。
   - 有效贡献定义：
     - 非简单的文档错别字修复
     - 非简单的代码格式化调整（如仅调整缩进、空格等）
     - 需做出实质性贡献（如功能开发、Bug 修复、性能优化、架构调整、技术文档编写、PR 审核等）
   - 示例合格贡献：新增功能模块、修复逻辑错误、优化算法效率、编写技术文档等

#### **时间范围**
   - 每月 1 日至月末最后一天合并的 PR 计入当月统计

### 二、申请流程
#### **申请条件**
   - PR 需被成功合并至[funstory-ai/BabelDOC](https://github.com/funstory-ai/BabelDOC/pulls) 仓库或 [Byaidu/PDFMathTranslate](https://github.com/Byaidu/PDFMathTranslate/pulls)的主分支。
   - 审核 PR、撰写 wiki 等贡献也必须是以上两个仓库。
   - 同一贡献者每月仅可申请一次（无论提交 PR 数量）
   - 同一贡献者每月最多可以获得 1 个兑换码
   - 对于 PR，只有发起者可以申请兑换码
   - 仅可使用当月的贡献申请兑换码（特殊情况请联系 aw@funstory.ai 说明）

#### **申请方式**
   - 发送邮件至 **aw@funstory.ai**
   - 邮件标题格式：`[贡献者会员兑换码申请] GitHub用户名-月份`（例：`[贡献者会员兑换码申请] awwaawwa-2024-07`）
   - 邮件正文需包含：
     - GitHub 用户名
     - 合并 PR 的完整链接
   - 附件要求：
     - PR 页面完整截图（需包含合并状态、仓库名称及点击头像后弹出来的侧边栏，如下图所示）

![附件示例](https://s.immersivetranslate.com/assets/r2-uploads/images/babeldoc-contributor_reward_example.png)

#### **奖励说明**
   - 奖励内容：[沉浸式翻译（Immersive Translate）](https://immersivetranslate.com/zh-Hans/pricing/)月度会员兑换码
   - 兑换码使用：在[沉浸式翻译官网兑换页](https://immersivetranslate.com/zh-Hans/exchange)输入即可激活
   - 会员权益：沉浸式翻译 Pro 会员一个月（详见[官网价格页](https://immersivetranslate.com/zh-Hans/pricing/)说明）
   - 兑换码为专属福利，不可转让

### 三、审核与发放
#### **审核周期**
   - 我们会尽力在收到申请邮件后 1 个工作日内完成审核
   - 审核时间可能因申请数量、审核复杂度等因素有所延长
   - 审核通过后，兑换码将通过邮件方式发送
   - 若审核未通过，我们会通过邮件说明原因

#### **兑换码规则**
   - 使用方式：[官网兑换页](https://immersivetranslate.com/zh-Hans/exchange)输入兑换码激活
   - 权益内容：月度会员（具体权益见[官网价格页](https://immersivetranslate.com/zh-Hans/pricing/)说明）
   - 不可转让

### 四、注意事项
#### **禁止行为**
   - 将完整功能拆分为多个无关 PR 提交
   - 提交质量不合格或具有潜在危害的代码
   - 提供虚假或误导性的申请材料

#### **特别说明**
   - funstory.ai 保留对贡献价值的评估权、规则的最终解释权等所有必要权利
   - 规则如有实质性更新（格式调整等除外），将提前 1 天在 [BabelDOC GitHub PR](https://github.com/funstory-ai/BabelDOC/pulls) 公告
   - 过期未使用的兑换码不予补发
   - 自 2025 年 2 月 1 日起的贡献可以申请兑换码
   - 为了确认您是 Pull Request (PR) 的发起者，防止他人冒领，我们可能会要求您使用发起者账号在 PR 下方留言指定的随机数字。

## 常见问题解答（FAQ）

**Q：如何判断文档翻译贡献是否有效？**

A：系统性的人工翻译（如完整章节的翻译并经过人工校对）视为有效贡献。零散段落翻译或仅依赖机器翻译的内容不计入有效贡献。

**Q：兑换码过期了可以补发吗？**

   A：为确保公平性，过期的兑换码将不予补发，请在有效期内及时使用。

**Q：为什么这个文档是中文的？**

A：因为目前应该是中文贡献者多吧，所以就先写中文的。后面再撰写英文版的。

---
**规则公示**：本规则文档存放于 BabelDOC 仓库 [CONTRIBUTOR_REWARD.md](https://github.com/funstory-ai/BabelDOC/blob/main/docs/CONTRIBUTOR_REWARD.md)，并在 [Contributor Reward - BabelDOC](https://funstory-ai.github.io/BabelDOC/CONTRIBUTOR_REWARD/) 展示。
